@@ -57,8 +57,9 @@ select
     CASE WHEN c_cli.COMANDA_ID IS NULL THEN cd_comu.PAIS_CODI ELSE c_cli_comu.PAIS_CODI END CODI_PAIS,
     CASE WHEN c_cli.COMANDA_ID IS NULL THEN NULL ELSE c_cli.TELEFON END TELEFON,
     CASE WHEN c_cli.COMANDA_ID IS NULL THEN NULL ELSE c_cli.EMAIL END MAIL,
-    cd.PES_NET, cd.PES_BRUT
-
+    cd.PES_NET, cd.PES_BRUT,
+    c.obs_comanda,
+    cd.obs_distribucio
 from comandes c
 join comandes_distribucio cd on c.ID = cd.COMANDA_ID
 join adreces_distribucio cd_adr on cd.ADRECA_DISTRIBUCIO_ID = cd_adr.ID
